<!DOCTYPE html>{% load i18n lib_tags amavis_tags %}
{% load static %}
<html lang="{{ LANGUAGE_CODE }}">
  <head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <meta http-equiv="X-UA-Compatible" content="IE=edge" />
    <title>Modoboa</title>
    <link rel="icon" type="image/png" href="{% static 'css/logo-icon.png' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'bootstrap/dist/css/bootstrap.min.css' %}" />
    <link rel="stylesheet" type="text/css" href="{% static 'modoboa_amavis/css/selfservice.css' %}" />
  </head>
  
  <body>
    <div id="fixed_content">
      <div id="menubar">{% viewm_menu_simple user mail_id rcpt secret_id %}</div>
      <div id="listing">{{ content }}</div>
    </div>

    <script src="{% static 'jquery/jquery.min.js' %}" type="text/javascript"></script>
    <script src="{% static 'bootstrap/dist/js/bootstrap.min.js' %}" type="text/javascript"></script>
    <script src="{% static 'js/global.js' %}" type="text/javascript"></script>
    <script src="{% static 'js/notify.js' %}" type="text/javascript"></script>
    <script src="{% static 'modoboa_amavis/js/selfservice.js' %}" type="text/javascript"></script>
    {% url "django.views.i18n.javascript_catalog" as catalog_url %}
    <script type="text/javascript" src="{{ catalog_url }}"></script>
    <script type="text/javascript">
        set_media_url("{{ STATIC_URL }}");
    </script>
  </body>
</html>
