{% load i18n lib_tags %}

{% blocktrans count counter=total %}
  {{ counter }} release request is pending for action.
{% plural %}
  {{ counter }} release requests are pending for action.
{% endblocktrans %}
{% trans "Sketch:" %}
{% for msg in requests %}
  {% trans "From:" %} {{ msg.mail.sid.email }}
  {% trans "To:" %} {{ msg.rid.email }}
  {% trans "Date:" %} {{ msg.mail.time_num|fromunix|date:"DATETIME_FORMAT" }}
  {% trans "Subject:" %} {{ msg.mail.subject }}
  {% trans "Act on this message:" %} {{ baseurl }}{% url "modoboa_amavis:index" %}#{{ msg.mail.mail_id }}/?rcpt={{ msg.rid.email }}
{% endfor %}
{% blocktrans %}Please visit {{ listingurl }} for a full listing.{% endblocktrans %}
