{% load lib_tags i18n %}
<div class="row">

  <div class="col-xs-7 col-md-5 col-lg-4">
    <div class="btn-group" title="{% trans 'Select' %}">
      <a class="btn btn-default"><input type="checkbox" id="selectall" /></a>
      <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown">
        <span class="caret"></span>
      </button>
      <ul class="dropdown-menu">
        <li><a name="selectmsgs" href="C">{% trans "Clean" %}</a></li>
        <li><a name="selectmsgs" href="S">{% trans "Spam" %}</a></li>
        <li><a name="selectmsgs" href="V">{% trans "Virus" %}</a></li>
        <li><a name="selectmsgs" href="H">{% trans "Bad Header" %}</a></li>
        <li><a name="selectmsgs" href="M">{% trans "Bad MIME" %}</a></li>
        <li><a name="selectmsgs" href="B">{% trans "Banned" %}</a></li>
      </ul>
    </div>
    
    <div class="btn-group" title="{% trans 'Release' %}">
      <a name="release-multi" href="{% url 'modoboa_amavis:mail_process' %}" class="btn btn-success disabled">
        <span class="fa fa-check"></span> {% trans 'Release' %}
      </a>
    </div>
    <div class="btn-group" title="{% trans 'Delete' %}">
      <a name="delete-multi" href="{% url 'modoboa_amavis:mail_process' %}" class="btn btn-danger disabled">
        <span class="fa fa-trash"></span> {% trans 'Delete' %}
      </a>
    </div>
    {% if manual_learning %}
    <div class="btn-group" title="{% trans 'Manual learning' %}">
      <button class="btn btn-default dropdown-toggle" data-toggle="dropdown">
        <span class="fa fa-cog"></span> <span class="caret"></span>
      </button>
      <ul class="dropdown-menu">
        <li><a name="mark-as-spam-multi" href="{% url 'modoboa_amavis:mail_process' %}">{% trans "Mark as spam" %}</a></li>
        <li><a name="mark-as-ham-multi" href="{% url 'modoboa_amavis:mail_process' %}">{% trans "Mark as non-spam" %}</a></li>
      </ul>
    </div>
    {% endif %}

  </div>
  
  <div class="col-xs-5 col-lg-4">
    {% include "common/email_searchbar.html" with extraopts=extraopts %}
  </div>

  <div class="hidden-md col-lg-4">
    <div class="btn-group">
      <div id="filters_bar" class="navbar-nav navbar-right">
        <span class="label label-default">{% trans "Display" %}</span>
        <div id="filters" class="btn-group" data-toggle="buttons">
          <label class="btn btn-default active">
            <input type="radio" name="msgtype_all" title="{% trans 'All messages' %}" checked> {% trans "All" %}
          </label>
          <label class="btn btn-success">
            <input type="radio" name="msgtype_C" title="{% trans 'Clean only' %}"> C
          </label>
          <label class="btn btn-danger">
            <input type="radio" name="msgtype_S" title="{% trans 'Spam only' %}"> S
          </label>
          <label class="btn btn-danger">
            <input type="radio" name="msgtype_V" title="{% trans 'Virus only' %}"> V
          </label>
          <label class="btn btn-warning">
            <input type="radio" name="msgtype_H" title="{% trans 'Bad Header only' %}"> H
          </label>
          <label class="btn btn-warning">
            <input type="radio" name="msgtype_M" title="{% trans 'Bad MIME only' %}"> M
          </label>
          <label class="btn btn-warning">
            <input type="radio" name="msgtype_B" title="{% trans 'Banned only' %}"> B
          </label>
        </div>
      </div>
    </div>
  </div>
  
</div>
